@@ -45,7 +45,6 @@
 #include <AkonadiWidgets/entitytreeview.h>
 #include <AkonadiWidgets/etmviewstatesaver.h>
 #include <AkonadiCore/favoritecollectionsmodel.h>
-#include <AkonadiCore/quotacolorproxymodel.h>
 #include <AkonadiCore/tagmodel.h>
 #include <AkonadiCore/statisticsproxymodel.h>
 #include <AkonadiCore/tagdeletejob.h>
@@ -167,11 +166,8 @@ BrowserWidget::BrowserWidget(KXmlGuiWindow *xmlGuiWindow, QWidget *parent) :
     statisticsProxyModel->setToolTipEnabled(true);
     statisticsProxyModel->setSourceModel(collectionFilter);
 
-    Akonadi::QuotaColorProxyModel *quotaProxyModel = new Akonadi::QuotaColorProxyModel(this);
-    quotaProxyModel->setWarningThreshold(50.0);
-    quotaProxyModel->setSourceModel(statisticsProxyModel);
 
-    mCollectionView->setModel(quotaProxyModel);
+    mCollectionView->setModel(statisticsProxyModel);
 
     Akonadi::SelectionProxyModel *selectionProxyModel = new Akonadi::SelectionProxyModel(mCollectionView->selectionModel(), this);
     selectionProxyModel->setSourceModel(mBrowserModel);
@@ -200,7 +196,6 @@ BrowserWidget::BrowserWidget(KXmlGuiWindow *xmlGuiWindow, QWidget *parent) :
     itemUi.modelBox->addItem(QStringLiteral("Generic"));
     itemUi.modelBox->addItem(QStringLiteral("Mail"));
     itemUi.modelBox->addItem(QStringLiteral("Contacts"));
-    itemUi.modelBox->addItem(QStringLiteral("Calendar"));
     itemUi.modelBox->addItem(QStringLiteral("Calendar/Tasks"));
     connect(itemUi.modelBox, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &BrowserWidget::modelChanged);
     QTimer::singleShot(0, this, &BrowserWidget::modelChanged);
@@ -212,7 +207,7 @@ BrowserWidget::BrowserWidget(KXmlGuiWindow *xmlGuiWindow, QWidget *parent) :
     connect(itemUi.itemView, SIGNAL(clicked(QModelIndex)), SLOT(itemActivated(QModelIndex)));
 
     splitter3->addWidget(itemViewParent);
-    itemViewParent->layout()->setMargin(0);
+    itemViewParent->layout()->setContentsMargins(0, 0, 0, 0);
 
     QWidget *contentViewParent = new QWidget(this);
     contentUi.setupUi(contentViewParent);
